{% extends "admin/change_form.html" %}
{% load i18n %}
{% block object-tools-items %}
  <li>
    <a href="{% url 'send_mass_email' pk=original.pk %}">{% trans "Send to all users" %}</a>
  </li>
  {{ block.super }}
{% endblock %}
